@@ -10,7 +10,6 @@ from cgdb.managers import TimeStepsManager
 from cgdb.resources import Site
 from cgdb.resources import StationGroup
 from cgdb.resources import Element
-from cgdb.resources import Department
 from cgdb.resources import Aggregation
 from cgdb.resources import ElementContext
 from cgdb.resources import TimeStep
@@ -170,7 +169,7 @@ class CGDB:
                                             self.time_step(time_step_code))
         self._data_sets_manager.create_data_set(site, element_code, aggregation_code, time_step_code, level_code, data_set_type, elementMarkOverride,)
 
-    def create_station(self, name: str, code: str, gpsLatitude: float, gpsLongitude: float, altitude: int, stationNetworkCode, remark=""):
+    def create_station(self, name: str, code: str, gpsLatitude: float, gpsLongitude: float, altitude: int, stationNetworkCode:str, stationGroupCode:str = None, remark=""):
         """Create station
 
              :type name: str
@@ -191,7 +190,7 @@ class CGDB:
             :type stationNetworkCode: str
             :param stationNetworkCode: code of station network that station is member of
          """
-        self._sites_manager.create_station(name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, remark)
+        self._sites_manager.create_station(name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, stationGroupCode, remark)
 
     def create_station_group(self, code, name, description):
         """Create station
