@@ -22,15 +22,19 @@ class SitesManager(ManagerMix):
 
         return Site(**content, client=self._client)
 
-    def create_station(self, name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, remark=""):
+    def create_station(self, name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, stationGroupCode=None, remark=""):
         station_network = self._client._station_networks_manager.station_network_by_code(stationNetworkCode)
         out = {"name": name,
-                "remark": remark,
-                "code": code,
-                "gpsLatitude": gpsLatitude,
-                "gpsLongitude": gpsLongitude,
-                "altitude": altitude,
-                "stationNetworkId": station_network.id}
+               "remark": remark,
+               "code": code,
+               "gpsLatitude": gpsLatitude,
+               "gpsLongitude": gpsLongitude,
+               "altitude": altitude,
+               "stationNetworkId": station_network.id}
+        if stationGroupCode is not None:
+            station_group = self._client.station_group(stationGroupCode)
+            out["stationGroupId"] = station_group.id
+
         result = self.post("sites", json.dumps(out))
         if result.status_code != 200:
             raise Exception("upload fail on server side\n Server error:"+result.content.decode("ASCII"))
